==> owntone-dmo_28.6.orig.tar.xz: owntone-28.6/web-src/src/icons.js <==
import {
  mdiAccountMusic,
  mdiAlbum,
  mdiArrowCollapseDown,
  mdiBookOpenPageVariant,
  mdiBookOpenVariant,
  mdiBookshelf,
  mdiBroadcast,
  mdiCancel,
  mdiCast,
  mdiCastVariant,
  mdiCellphone,
  mdiCheck,
  mdiChevronDown,
  mdiChevronUp,
  mdiContentSave,
  mdiDelete,
  mdiDeleteEmpty,
  mdiDotsHorizontal,
  mdiDotsVertical,
  mdiDragHorizontal,
  mdiFastForward,
  mdiFileMusic,
  mdiFileOutline,
  mdiFire,
  mdiFolder,
  mdiFolderOpen,
  mdiMagnify,
  mdiMenu,
  mdiMicrophone,
  mdiMusic,
  mdiMusicBoxMultiple,
  mdiOpenInNew,
  mdiPause,
  mdiPencil,
  mdiPipe,
  mdiPlay,
  mdiPlaylistPlay,
  mdiPlaylistPlus,
  mdiRadio,
  mdiRadioTower,
  mdiRefresh,
  mdiRepeat,
  mdiRepeatOff,
  mdiRepeatOnce,
  mdiRewind,
  mdiRss,
  mdiServer,
  mdiShuffle,
  mdiShuffleDisabled,
  mdiSkipBackward,
  mdiSkipForward,
  mdiSpeaker,
  mdiSpotify,
  mdiStop,
  mdiSubdirectoryArrowLeft,
  mdiVolumeHigh,
  mdiVolumeOff,
  mdiWeb
} from '@mdi/js'

export const icons = {
  mdiAccountMusic,
  mdiAlbum,
  mdiArrowCollapseDown,
  mdiBookOpenPageVariant,
  mdiBookOpenVariant,
  mdiBookshelf,
  mdiBroadcast,
  mdiCancel,
  mdiCast,
  mdiCastVariant,
  mdiCellphone,
  mdiCheck,
  mdiChevronDown,
  mdiChevronUp,
  mdiContentSave,
  mdiDelete,
  mdiDeleteEmpty,
  mdiDotsHorizontal,
  mdiDotsVertical,
  mdiDragHorizontal,
  mdiFastForward,
  mdiFileMusic,
  mdiFileOutline,
  mdiFire,
  mdiFolder,
  mdiFolderOpen,
  mdiMagnify,
  mdiMenu,
  mdiMicrophone,
  mdiMusic,
  mdiMusicBoxMultiple,
  mdiOpenInNew,
  mdiPause,
  mdiPencil,
  mdiPipe,
  mdiPlay,
  mdiPlaylistPlay,
  mdiPlaylistPlus,
  mdiRadio,
  mdiRadioTower,
  mdiRefresh,
  mdiRepeat,
  mdiRepeatOff,
  mdiRepeatOnce,
  mdiRewind,
  mdiRss,
  mdiServer,
  mdiShuffle,
  mdiShuffleDisabled,
  mdiSkipBackward,
  mdiSkipForward,
  mdiSpeaker,
  mdiSpotify,
  mdiStop,
  mdiSubdirectoryArrowLeft,
  mdiVolumeHigh,
  mdiVolumeOff,
  mdiWeb
}

==> owntone-dmo_29.0.orig.tar.xz: owntone-29.0/web-src/src/icons.js <==
import {
  mdiAccountMusic,
  mdiAlbum,
  mdiBookOpenPageVariant,
  mdiBookOpenVariant,
  mdiBookshelf,
  mdiBroadcast,
  mdiCancel,
  mdiCast,
  mdiCastVariant,
  mdiCheck,
  mdiChevronDown,
  mdiChevronLeft,
  mdiChevronUp,
  mdiClose,
  mdiDelete,
  mdiDeleteEmpty,
  mdiDotsHorizontal,
  mdiDotsVertical,
  mdiDownload,
  mdiDragHorizontal,
  mdiEyeOffOutline,
  mdiFastForward30,
  mdiFileMusicOutline,
  mdiFire,
  mdiFolder,
  mdiFolderOpen,
  mdiHistory,
  mdiLoading,
  mdiMagnify,
  mdiMenu,
  mdiMicrophone,
  mdiMusic,
  mdiMusicBoxMultiple,
  mdiOpenInNew,
  mdiPause,
  mdiPencil,
  mdiPipe,
  mdiPlay,
  mdiPlaylistMusic,
  mdiPlaylistPlay,
  mdiPlaylistPlus,
  mdiRadio,
  mdiRadioTower,
  mdiRefresh,
  mdiRepeat,
  mdiRepeatOff,
  mdiRepeatOnce,
  mdiRewind10,
  mdiRss,
  mdiScriptTextOutline,
  mdiScriptTextPlay,
  mdiServer,
  mdiShuffle,
  mdiShuffleDisabled,
  mdiSkipBackward,
  mdiSkipForward,
  mdiSpeaker,
  mdiSpotify,
  mdiStop,
  mdiVectorLink,
  mdiVolumeHigh,
  mdiVolumeOff,
  mdiWeb
} from '@mdi/js'

export const icons = {
  mdiAccountMusic,
  mdiAlbum,
  mdiBookOpenPageVariant,
  mdiBookOpenVariant,
  mdiBookshelf,
  mdiBroadcast,
  mdiCancel,
  mdiCast,
  mdiCastVariant,
  mdiCheck,
  mdiChevronDown,
  mdiChevronLeft,
  mdiChevronUp,
  mdiClose,
  mdiDelete,
  mdiDeleteEmpty,
  mdiDotsHorizontal,
  mdiDotsVertical,
  mdiDownload,
  mdiDragHorizontal,
  mdiEyeOffOutline,
  mdiFastForward30,
  mdiFileMusicOutline,
  mdiFire,
  mdiFolder,
  mdiFolderOpen,
  mdiHistory,
  mdiLoading,
  mdiMagnify,
  mdiMenu,
  mdiMicrophone,
  mdiMusic,
  mdiMusicBoxMultiple,
  mdiOpenInNew,
  mdiPause,
  mdiPencil,
  mdiPipe,
  mdiPlay,
  mdiPlaylistMusic,
  mdiPlaylistPlay,
  mdiPlaylistPlus,
  mdiRadio,
  mdiRadioTower,
  mdiRefresh,
  mdiRepeat,
  mdiRepeatOff,
  mdiRepeatOnce,
  mdiRewind10,
  mdiRss,
  mdiScriptTextOutline,
  mdiScriptTextPlay,
  mdiServer,
  mdiShuffle,
  mdiShuffleDisabled,
  mdiSkipBackward,
  mdiSkipForward,
  mdiSpeaker,
  mdiSpotify,
  mdiStop,
  mdiVectorLink,
  mdiVolumeHigh,
  mdiVolumeOff,
  mdiWeb
}
